==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/sharebymail/l10n/sl.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "V skupni rabi %1$s",
    "Shared with {email}" : "V skupni rabi z {email}",
    "Password for mail share sent to %1$s" : "Geslo za dostop je bilo poslano na %1$s",
    "Password for mail share sent to {email}" : "Geslo za dostop je bilo poslano na {email}.",
    "Password to access %1$s was sent to %2s" : "Geslo za dostop do datoteke %1$s je bilo poslano na %2s.",
    "Password to access {file} was sent to {email}" : "Geslo za dostop do datoteke {file} je bilo poslano na {email}.",
    "Password to access %1$s was sent to you" : "Geslo za dostop do datoteke %1$s je bilo poslano vaš elektronski naslov.",
    "Password to access {file} was sent to you" : "Geslo za dostop do datoteke {file} je bilo poslano vaš elektronski naslov.",
    "Failed to send share by email" : "Pošiljanje povezave po elektronski pošti je spodletelo.",
    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s vam omogoča souporabo »%2$s«.\nPo elektronski pošti bi morali prejeti tudi ločeno sporočilo s povezavo.\n",
    "Password to access »%s«" : "Geslo za dostop do »%s«",
    "It is protected with the following password:" : "Zaščiten je z geslom:",
    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
    "This is the password:" : "Geslo:",
    "You can choose a different password at any time in the share dialog." : "Geslo je mogoče kadarkoli spremeniti med nastavitvami souporabe.",
    "Could not find share" : "Mape v souporabi ni mogoče najti",
    "Share by mail" : "Souporaba prek elektronske pošte",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Dovoli uporabnikom omogočanje souporabe prek osebne povezave na datoteko ali mapo z vpisom elektronskega naslova.",
    "Send password by mail" : "Pošlji geslo po elektronski pošti",
    "Enforce password protection" : "Vsili zaščito z geslom"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/sharebymail/l10n/sl.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "V skupni rabi %1$s",
    "Shared with {email}" : "V skupni rabi z {email}",
    "Password for mail share sent to %1$s" : "Geslo za dostop je bilo poslano na %1$s",
    "Password for mail share sent to {email}" : "Geslo za dostop je bilo poslano na {email}.",
    "You shared %1$s with %2$s by mail" : "Omogočite souporabo datoteke %1$sprek elektronskega naslova %2$s.",
    "You shared {file} with {email} by mail" : "Omogočite souporabo datoteke {file} prek elektronskega naslova {email}.",
    "%3$s shared %1$s with %2$s by mail" : "%3$s omogoči souporabo datoteke %1$s prek elektronskega naslova %2$s.",
    "{actor} shared {file} with {email} by mail" : "{actor} omogoči souporabo datoteke {file} prek elektronskega naslova {email}.",
    "You unshared %1$s from %2$s by mail" : "Onemogočite souporabo datoteke %1$sprek elektronskega naslova %2$s.",
    "You unshared {file} from {email} by mail" : "Onemogočite souporabo datoteke {file} prek elektronskega naslova {email}.",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s onemogoči souporabo datoteke %1$s prek elektronskega naslova %2$s.",
    "{actor} unshared {file} from {email} by mail" : "{actor} onemogoči souporabo datoteke {file} prek elektronskega naslova {email}.",
    "Password to access %1$s was sent to %2s" : "Geslo za dostop do datoteke %1$s je bilo poslano na %2s.",
    "Password to access {file} was sent to {email}" : "Geslo za dostop do datoteke {file} je bilo poslano na {email}.",
    "Password to access %1$s was sent to you" : "Geslo za dostop do datoteke %1$s je bilo poslano vaš elektronski naslov.",
    "Password to access {file} was sent to you" : "Geslo za dostop do datoteke {file} je bilo poslano vaš elektronski naslov.",
    "Failed to send share by email" : "Pošiljanje povezave po elektronski pošti je spodletelo.",
    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s vam omogoča souporabo »%2$s«.\nPo elektronski pošti bi morali prejeti tudi ločeno sporočilo s povezavo.\n",
    "Password to access »%s«" : "Geslo za dostop do »%s«",
    "It is protected with the following password:" : "Zaščiten je z geslom:",
    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
    "This is the password:" : "Geslo:",
    "You can choose a different password at any time in the share dialog." : "Geslo je mogoče kadarkoli spremeniti med nastavitvami souporabe.",
    "Could not find share" : "Mape v souporabi ni mogoče najti",
    "Share by mail" : "Souporaba prek elektronske pošte",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Dovoli uporabnikom omogočanje souporabe prek osebne povezave na datoteko ali mapo z vpisom elektronskega naslova.",
    "Send password by mail" : "Pošlji geslo po elektronski pošti",
    "Enforce password protection" : "Vsili zaščito z geslom"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
